// This file is part of Desktop App Toolkit,
// a set of libraries for developing nice desktop applications.
//
// For license and copyright information please follow this link:
// https://github.com/desktop-app/legal/blob/master/LEGAL
//
#include "base/platform/win/base_haptic_win.h"

namespace base::Platform {

void Haptic() {
}

bool IsSwipeBackEnabled() {
	return true;
}

} // namespace base::Platform
